@@ -1,10 +1,9 @@
 """Mongo data models."""
 
-
 from mongoengine.fields import (Document, StringField, DateTimeField,
                                 ListField, IntField, EmbeddedDocument,
                                 EmbeddedDocumentListField, BooleanField,
-                                DictField, FloatField)
+                                DictField, FloatField, EmbeddedDocumentField)
 
 
 class RepoEvents(Document):
@@ -12,25 +11,22 @@ class RepoEvents(Document):
 
     Attributes:
         event_type (StringField): The GitHub event type https://developer.github.com/v3/activity/event_types
-        repo_name (StringField): The full name of the GitHub repo.
+        organization (StringField): The organization name of the GitHub repo.
+        repository (StringField): The name of the GitHub repo.
         timestamp (DateTimeField): The datetime timestamp of the event.
     """
 
     meta = {'allow_inheritance': True}
 
     # Static list of valid event types
-    valid_event_types = ("ReleaseEvent", "PushEvent", "PullRequestEvent")
+    valid_event_types = ("ReleaseEvent", "CommitEvent", "PullEvent")
 
     # Crawler fields
     event_type = StringField(required=True, choices=valid_event_types)
-    repo_name = StringField(required=True)
+    organization = StringField(required=True)
+    repository = StringField(required=True)
     timestamp = DateTimeField(required=True)
 
-    def __init__(self, **kwargs):
-        """Pass any init parameters to the Document class."""
-        Document.__init__(self, **kwargs)
-
-
 class LinterScanEvent(EmbeddedDocument):
     """A sub-document for static analysis events.
 
@@ -54,13 +50,12 @@ class LinterScanEvent(EmbeddedDocument):
 
 class ReleaseEvent(RepoEvents):
     """The GitHub release events model."""
-
     def __init__(self, **kwargs):
         RepoEvents.__init__(self, **kwargs)
         self.event_type = "ReleaseEvent"
 
 
-class PullRequestEvent(RepoEvents):
+class PullEvent(RepoEvents):
     """The GitHub pull requests events model."""
 
     sha = StringField(required=True)
@@ -74,7 +69,7 @@ class PullRequestEvent(RepoEvents):
 
     def __init__(self, **kwargs):
         RepoEvents.__init__(self, **kwargs)
-        self.event_type = "PullRequestEvent"
+        self.event_type = "PullEvent"
 
 
 class InvestmentKPI(EmbeddedDocument):
@@ -86,6 +81,17 @@ class InvestmentKPI(EmbeddedDocument):
     devops = FloatField(default=0.0)
     debt = FloatField(default=0.0)
 
+    def __init__(self, load_dict, **kwargs):
+        EmbeddedDocument.__init__(self, **kwargs)
+        self.load(load_dict)
+
+    def load(self, load_dict):
+        self.total = load_dict["total"]
+        self.features = load_dict["features"]
+        self.defects = load_dict["defects"]
+        self.devops = load_dict["devops"]
+        self.debt = load_dict["debt"]
+
 
 class MaturityKPI(EmbeddedDocument):
     """The maturity KPI total and sub-totals."""
@@ -96,6 +102,17 @@ class MaturityKPI(EmbeddedDocument):
     automation = FloatField(default=0.0)
     security = FloatField(default=0.0)
 
+    def __init__(self, load_dict, **kwargs):
+        EmbeddedDocument.__init__(self, **kwargs)
+        self.load(load_dict)
+
+    def load(self, load_dict):
+        self.total = load_dict["total"]
+        self.assets = load_dict["assets"]
+        self.tooling = load_dict["tooling"]
+        self.automation = load_dict["automation"]
+        self.security = load_dict["security"]
+
 
 class QualityKPI(EmbeddedDocument):
     """The quality KPI total and sub-totals."""
@@ -106,6 +123,17 @@ class QualityKPI(EmbeddedDocument):
     static_analyis = FloatField(default=0.0)
     deploy = FloatField(default=0.0)
 
+    def __init__(self, load_dict, **kwargs):
+        EmbeddedDocument.__init__(self, **kwargs)
+        self.load(load_dict)
+
+    def load(self, load_dict):
+        self.total = load_dict["total"]
+        self.pipeline = load_dict["pipeline"]
+        self.testing = load_dict["testing"]
+        self.static_analysis = load_dict["static_analysis"]
+        self.deploy = load_dict["deploy"]
+
 
 class RiskKPI(EmbeddedDocument):
     """The risk KPI total and sub-totals."""
@@ -113,6 +141,14 @@ class RiskKPI(EmbeddedDocument):
     total = FloatField(default=0.0)
     secrets = FloatField(default=0.0)
 
+    def __init__(self, load_dict, **kwargs):
+        EmbeddedDocument.__init__(self, **kwargs)
+        self.load(load_dict)
+
+    def load(self, load_dict):
+        self.total = load_dict["total"]
+        self.secrets = load_dict["secrets"]
+
 
 class VelocityKPI(EmbeddedDocument):
     """The velocity KPI total and sub-totals."""
@@ -121,6 +157,15 @@ class VelocityKPI(EmbeddedDocument):
     commit = FloatField(default=0.0)
     merge_frequency = FloatField(default=0.0)
 
+    def __init__(self, load_dict, **kwargs):
+        EmbeddedDocument.__init__(self, **kwargs)
+        self.load(load_dict)
+
+    def load(self, load_dict):
+        self.total = load_dict["total"]
+        self.tags = load_dict["commit"]
+        self.identifiers = load_dict["merge_frequency"]
+
 
 class InfrastructureKPI(EmbeddedDocument):
     """The infrastructure KPI total and sub-totals."""
@@ -131,9 +176,20 @@ class InfrastructureKPI(EmbeddedDocument):
     compute_resources = FloatField(default=0.0)
     environments = FloatField(default=0.0)
 
+    def __init__(self, load_dict, **kwargs):
+        EmbeddedDocument.__init__(self, **kwargs)
+        self.load(load_dict)
 
-class PushEvent(RepoEvents):
-    """The GitHub push events model.
+    def load(self, load_dict):
+        self.total = load_dict["total"]
+        self.tags = load_dict["tags"]
+        self.identifiers = load_dict["identifiers"]
+        self.compute_resources = load_dict["compute_resources"]
+        self.environments = load_dict["environments"]
+
+
+class CommitEvent(RepoEvents):
+    """The GitHub commit events model.
 
     Attributes:
         sha (StringField): The SHA of the most recent commit on ref after the push.
@@ -143,9 +199,12 @@ class PushEvent(RepoEvents):
         LinterScanEvents (Document): A sub-document for static analysis events.
     """
 
-    # Push fields
+    # Commit fields
     sha = StringField(required=True)
-    ref = StringField(required=True)
+    additions = IntField(default=0)
+    deletions = IntField(default=0)
+    total = IntField(default=0)
+    commit_files = ListField()
 
     # Crawler flags
     actor = DictField()
@@ -154,22 +213,21 @@ class PushEvent(RepoEvents):
     files = ListField()
 
     # Linter fields
-    linter_warnings_total = IntField()
-    linter_errors_total = IntField()
+    linter_warnings_total = IntField(default=0)
+    linter_errors_total = IntField(default=0)
     linter_events = EmbeddedDocumentListField(LinterScanEvent)
 
     # Analysis fields
-    investment_kpi = InvestmentKPI()
-    maturity_kpi = MaturityKPI()
-    quality_kpi = QualityKPI()
-    risk_kpi = RiskKPI()
-    velocity_kpi = VelocityKPI()
-    infra_kpi = InfrastructureKPI()
+    investment_kpi = EmbeddedDocumentField(InvestmentKPI)
+    maturity_kpi = EmbeddedDocumentField(MaturityKPI)
+    quality_kpi = EmbeddedDocumentField(QualityKPI)
+    risk_kpi = EmbeddedDocumentField(RiskKPI)
+    velocity_kpi = EmbeddedDocumentField(VelocityKPI)
+    infra_kpi = EmbeddedDocumentField(InfrastructureKPI)
 
     def __init__(self, **kwargs):
         RepoEvents.__init__(self, **kwargs)
-        self.event_type = "PushEvent"
-
+        self.event_type = "CommitEvent"
 
 class PipelineRun(Document):
     name = StringField(max_length=120, required=True)
@@ -185,8 +243,4 @@ class PipelineRun(Document):
     fail_stage = StringField(max_length=50)
     fail_logs = StringField(max_length=10000)
     tags = ListField(StringField(max_length=30))
-    meta = {
-        'indexes': [
-            'name'
-        ]
-    }
+    meta = {'indexes': ['name']}
